function in_data = fem_input

% fem_input.m - input file for FEM analysis  

% 2-D poromechanics mechanics element. Linking stress and flow. 3 node constant strain/pressure-gradient triangle 

% Control Data: [   nodes            % Total number of nodes
%                   numel            % Total number of elements
%                   nodaldof         % Max dof per node
%                   nodesperelement  % Max nodes per element
%                   numat            % Max mumber of materials
%                   ndimensions      % Number of space dimensions  ]

in_data.control = [4 2 3 3 1 2 ];

% Nodal Data: [ node# x1 x2 x3] 
in_data.ND = [   
   1   1   1;
   2   2   1;
   3   1   2;
   4   2   2];
   
% Material Property Data: [ 
%                      Element type for material no. 1
%                      Element parameter 1 (Deformation modulus)
%                      Element parameter 2 (Poisson Ratio)
%                      Element parameter 3 (Permeability)
%                      Element parameter 4 (Porosity)
%                      Element parameter 5 (Fluid Stiffness, Kf)
 in_data.mater = [25 100.0 0.0 1 0.0 1];
                               

% Element Association Data: [ element# materialtype# node1# node2# ....] 
in_data.EL = [  
   1   1   1   2   3;
   2   1   2   4   3]; 
   
% Nodal Constraint Data: [ node# x1_disp x2_disp.... etc ] 
% 1 = fixed displacement; 0 = non-fixed displacement
in_data.CON = [  
   1   1   1   0;
   2   0   1   0;
   3   0   0   0;
   4   0   0   0];

% Nodal Load Data: [node# x1_load x2_load..... etc] 
% Magnitude of prescribed load OR displacement
in_data.LOAD = [ 
   1   0   0   0;
   2   0   0   0;
   3   0  -1   0;
   4   0  -1   0];

 